package cn.wisenergy.web.admin.controller.app;


import cn.wisenergy.common.utils.R;
import cn.wisenergy.model.app.RefillCard;
import cn.wisenergy.model.dto.RefillCardDto;
import cn.wisenergy.model.vo.RefillCardVo;
import cn.wisenergy.service.app.RefillCardService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.math.BigInteger;
import java.text.DecimalFormat;
import java.util.Date;

@Api(tags = "充值卡管理")
@RestController
@RequestMapping("/refillCard")
@Slf4j
public class RefillCardController {

    @Autowired
    private RefillCardService refillCardService;

    @ApiOperation(value = "添加充值卡",notes = "添加充值卡",httpMethod = "POST")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "numbers",value = "卡的数量",dataType="int",required = true),
            @ApiImplicitParam(name = "cardNo",value = "充值卡初始序号",dataType="BigInteger")
    })
    @PostMapping("/manage")
    public R<Boolean> manage(Integer numbers,BigInteger cardNo){
        log.info("RefillCardController[].manage[].input.param,numbers"+numbers);
        //创建对象参数
        RefillCard refillCard = new RefillCard();
        refillCard.setCardNumber(numbers);
        refillCard.setCardNo(cardNo);
        return  refillCardService.add(refillCard);
    }

    @ApiOperation(value = "激活充值卡",notes = "激活充值卡",httpMethod = "POST")
    @ApiImplicitParam(name = "batchNumber",value = "批次号",dataType = "string",required = true)
    @PostMapping("/update")
    public R<Boolean> update(String batchNumber){
        log.info("RefillCardController[].manage[].input.param,batchNumber"+batchNumber);
        return refillCardService.update(batchNumber);
    }

    @ApiOperation(value = "充值卡查询",notes = "充值卡查询",httpMethod = "POST")
    @ApiImplicitParam(name = "refillCardVo",value = "每页显示条数",dataType="RefillCardVo")
    @PostMapping("/select")
    public R<PageInfo<RefillCardDto>> select(@RequestBody RefillCardVo refillCardVo){
        log.info("RefillCardController[].select[].input.param.refillCardVo"+refillCardVo);
        return refillCardService.getList(refillCardVo);
    }

    @ApiOperation(value = "生成卡片",notes = "生成卡片",httpMethod = "GET")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id",value = "充值卡id",dataType="int"),
    })
    @GetMapping("/createCard")
    public R<Boolean> createCard(Integer id){
        log.info("RefillCardController[].createCard[].input.param:id"+id);
        return refillCardService.createCard(id);
    }

    @ApiOperation(value = "充值卡导出",notes = "充值卡导出",httpMethod = "GET")
    @ApiImplicitParam(name = "batchNumber",value = "充值卡批次号",dataType = "string",required = true)
    @GetMapping(value = "/exportCard")
    public R<Boolean> exportCard(String batchNumber, HttpServletResponse response){
        log.info("RefillCardController[].exportCard[].input.param:batchNumber"+batchNumber);

        return refillCardService.createExcel(batchNumber,response);
    }

}
